==> nextcloud-28.0.3.tgz: nextcloud/apps/suspicious_login/l10n/nb.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Nytt påloggingssted oppdaget",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "En ny pålogging til kontoen din ble oppdaget. IP-adressen %s ble klassifisert som mistenkelig. Hvis dette var deg, kan du ignorere denne meldingen. Ellers bør du endre passordet ditt.",
    "Suspicious Login" : "Mistenkelig pålogging",
    "More information ↗" : "Mer informasjon ↗",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Du kan få mer info ved å trykke på knappen som vil åpne %s og vise info om den mistenkelige IP-adressen.",
    "New login detected" : "Ny pålogging oppdaget",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Oppdag og advar om mistenkelige IP-adresser som logger på Nextcloud\n\t",
    "Suspicious login detection" : "Oppdagelse av mistenkelig pålogging",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "Den mistenkelige påloggingsappen er aktivert på denne forekomsten. Det vil holde oversikt over IP-adresser brukere logger på fra og bygge en klassifiserer som advarer om en ny pålogging kommer fra en mistenkelig IP-adresse.",
    "Training data statistics" : "Treningsdatastatistikk",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Så langt har appen fanget opp {total} pålogginger (inkludert klienttilkoblinger), hvorav {distinct} er distinkte (IP, UID) tupler.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Statistikk for klassifikatormodeller",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Ingen klassifiseringsmodell har blitt trent enda. Dette betyr mest sannsynlig at du nettopp har aktivert appen nylig. Fordi opplæring av en modell krever gode data, venter appen til pålogginger på minst {dager} dager er registrert.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Under evalueringen har den nyeste modellen (trent {time}) vist seg å fange {recall}% av alle mistenkelige pålogginger (tilbakekalling), mens {presisjon}% av påloggingene klassifisert som mistenkelige faktisk er mistenkelige (presisjon). Nedenfor ser du en visualisering av historisk modellytelse.",
    "Precision" : "Presisjon",
    "Recall" : "Tilbakekalling"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.5.tgz: nextcloud/apps/suspicious_login/l10n/nb.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Nytt påloggingssted oppdaget",
    "More info about the suspicious IP address available on %s" : "Mer informasjon om den mistenkelige IP-adressen tilgjengelig på %s",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "En ny pålogging til kontoen din ble oppdaget. IP-adressen %s ble klassifisert som mistenkelig. Hvis dette var deg, kan du ignorere denne meldingen. Ellers bør du endre passordet ditt.",
    "Open %s ↗" : "Åpne %s ↗",
    "Suspicious Login" : "Mistenkelig pålogging",
    "New login detected" : "Ny pålogging oppdaget",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Oppdag og advar om mistenkelige IP-adresser som logger på Nextcloud\n\t",
    "Suspicious login detection" : "Oppdagelse av mistenkelig pålogging",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "Den mistenkelige påloggingsappen er aktivert på denne forekomsten. Det vil holde oversikt over IP-adresser brukere logger på fra og bygge en klassifiserer som advarer om en ny pålogging kommer fra en mistenkelig IP-adresse.",
    "Training data statistics" : "Treningsdatastatistikk",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Så langt har appen fanget opp {total} pålogginger (inkludert klienttilkoblinger), hvorav {distinct} er distinkte (IP, UID) tupler.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Statistikk for klassifikatormodeller",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Ingen klassifiseringsmodell har blitt trent enda. Dette betyr mest sannsynlig at du nettopp har aktivert appen nylig. Fordi opplæring av en modell krever gode data, venter appen til pålogginger på minst {dager} dager er registrert.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Under evalueringen har den nyeste modellen (trent {time}) vist seg å fange {recall}% av alle mistenkelige pålogginger (tilbakekalling), mens {presisjon}% av påloggingene klassifisert som mistenkelige faktisk er mistenkelige (presisjon). Nedenfor ser du en visualisering av historisk modellytelse.",
    "Precision" : "Presisjon",
    "Recall" : "Tilbakekalling",
    "More information ↗" : "Mer informasjon ↗",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Du kan få mer info ved å trykke på knappen som vil åpne %s og vise info om den mistenkelige IP-adressen."
},
"nplurals=2; plural=(n != 1);");
